Home
last modified time | relevance | path

Searched refs:__addr (Results 1 – 9 of 9) sorted by relevance

/freebsd-14.2/contrib/llvm-project/libcxx/include/__memory/
H A Dtemp_value.h37 _LIBCPP_HIDE_FROM_ABI _LIBCPP_CONSTEXPR_SINCE_CXX20 _Tp* __addr() { in __addr() function
45 _LIBCPP_HIDE_FROM_ABI _LIBCPP_CONSTEXPR_SINCE_CXX20 _Tp& get() { return *__addr(); } in get()
50 _Traits::construct(__a, __addr(), std::forward<_Args>(__args)...); in __temp_value()
53 …PP_HIDE_FROM_ABI _LIBCPP_CONSTEXPR_SINCE_CXX20 ~__temp_value() { _Traits::destroy(__a, __addr()); } in ~__temp_value()
/freebsd-14.2/contrib/llvm-project/libcxx/include/__coroutine/
H A Dcoroutine_handle.h48 _LIBCPP_HIDE_FROM_ABI static constexpr coroutine_handle from_address(void* __addr) noexcept {
50 __tmp.__handle_ = __addr;
118 _LIBCPP_HIDE_FROM_ABI static constexpr coroutine_handle from_address(void* __addr) noexcept {
120 __tmp.__handle_ = __addr;
/freebsd-14.2/contrib/llvm-project/clang/lib/Headers/
H A Dlwpintrin.h32 __llwpcb (void *__addr) in __llwpcb() argument
34 __builtin_ia32_llwpcb(__addr); in __llwpcb()
H A D__clang_hip_runtime_wrapper.h63 __device__ void __ockl_dm_dealloc(unsigned long long __addr);
67 __device__ void __asan_free_impl(unsigned long long __addr,
H A Darm_acle.h718 __arm_ld64b(const void *__addr) { in __arm_ld64b() argument
720 __builtin_arm_ld64b(__addr, __value.val); in __arm_ld64b()
724 __arm_st64b(void *__addr, data512_t __value) { in __arm_st64b() argument
725 __builtin_arm_st64b(__addr, __value.val); in __arm_st64b()
728 __arm_st64bv(void *__addr, data512_t __value) { in __arm_st64bv() argument
729 return __builtin_arm_st64bv(__addr, __value.val); in __arm_st64bv()
732 __arm_st64bv0(void *__addr, data512_t __value) { in __arm_st64bv0() argument
733 return __builtin_arm_st64bv0(__addr, __value.val); in __arm_st64bv0()
H A Dhtmxlintrin.h236 __TM_non_transactional_store (void* const __addr, long long const __value) in __TM_non_transactional_store() argument
238 __builtin_non_tx_store ((uint64_t*)__addr, (uint64_t)__value); in __TM_non_transactional_store()
H A Daltivec.h17749 return *(unaligned_vec_sint *)__addr; in vec_xl()
17755 return *(unaligned_vec_uint *)__addr; in vec_xl()
17772 return *(unaligned_vec_sll *)__addr; in vec_xl()
17778 return *(unaligned_vec_ull *)__addr; in vec_xl()
17943 return (unaligned_vec_ull) *__addr; in vec_xlds()
17956 return (vector signed int)*__addr; in vec_load_splats()
17962 return (vector signed int)*__addr; in vec_load_splats()
17968 return (vector unsigned int)*__addr; in vec_load_splats()
17974 return (vector unsigned int)*__addr; in vec_load_splats()
17980 return (vector float)*__addr; in vec_load_splats()
[all …]
/freebsd-14.2/sys/contrib/dev/rtw89/
H A Dmac.h478 ({typeof(_addr) __addr = (_addr); \
479 __addr >= R_AX_CMAC_REG_START && __addr <= R_AX_CMAC_REG_END; })
/freebsd-14.2/usr.sbin/bsdconfig/share/media/
H A Dtcpip.subr169 local __addr="$1" __var_to_set="$2" __num=0
170 if f_validate_ipaddr "$__addr"; then
172 set -- $__addr